==> mono-1.1.15.tar.gz: mono-1.1.15/mcs/class/corlib/System.Text/EncodingInfo.cs <==
//
// EncodingInfo.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.Text
{
	[Serializable]
	public sealed class EncodingInfo
	{
		readonly int codepage;
		readonly string display_name;
		readonly string name;

		internal EncodingInfo (int cp, string displayName, string name)
		{
			codepage = cp;
			display_name = displayName;
			this.name = name;
		}

		public int CodePage {
			get { return codepage; }
		}

		public string DisplayName {
			get { return display_name; }
		}

		public string Name {
			get { return name; }
		}

		public override bool Equals (object other)
		{
			EncodingInfo ei = other as EncodingInfo;
			return ei != null &&
				ei.codepage == codepage &&
				ei.name == name &&
				ei.display_name == display_name;
		}

		public override int GetHashCode ()
		{
			return codepage + (display_name.GetHashCode () ^ name.GetHashCode ()) << 16;
		}

		public Encoding GetEncoding ()
		{
			return Encoding.GetEncoding (codepage);
		}
	}
}

#endif

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/corlib/System.Text/EncodingInfo.cs <==
//
// EncodingInfo.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//

//
// Copyright (C) 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.Text
{
	[Serializable]
	public sealed class EncodingInfo
	{
		readonly int codepage;
		Encoding encoding;

		internal EncodingInfo (int cp)
		{
			codepage = cp;
		}

		public int CodePage {
			get { return codepage; }
		}

		[MonoTODO]
		public string DisplayName {
			get { return Name; }
		}

		public string Name {
			get {
				if (encoding == null)
					encoding = GetEncoding ();
				return encoding.WebName;
			}
		}

		public override bool Equals (object other)
		{
			EncodingInfo ei = other as EncodingInfo;
			return ei != null &&
				ei.codepage == codepage;
		}

		public override int GetHashCode ()
		{
			return codepage;
		}

		public Encoding GetEncoding ()
		{
			return Encoding.GetEncoding (codepage);
		}
	}
}

#endif
